<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://cynorwebsolutions.com
 * @since             1.0.0
 * @package           Whatsmarketing
 *
 * @wordpress-plugin
 * Plugin Name:       whatsmarketing
 * Plugin URI:        https://cynorwebsolutions.com
 * Description:       This is a description of the plugin.
 * Version:           1.0.0
 * Author:            MICHAEL PAREDES
 * Author URI:        https://cynorwebsolutions.com/
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       whatsmarketing
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'WHATSMARKETING_VERSION', '1.0.0' );

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-whatsmarketing-activator.php
 */
function activate_whatsmarketing() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-whatsmarketing-activator.php';
	Whatsmarketing_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-whatsmarketing-deactivator.php
 */
function deactivate_whatsmarketing() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-whatsmarketing-deactivator.php';
	Whatsmarketing_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_whatsmarketing' );
register_deactivation_hook( __FILE__, 'deactivate_whatsmarketing' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-whatsmarketing.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_whatsmarketing() {

	$plugin = new Whatsmarketing();
	$plugin->run();

}
run_whatsmarketing();
// Hook to add settings link on the plugins page
add_filter('plugin_action_links_' . plugin_basename(__FILE__), 'my_custom_plugin_settings_link');

function my_custom_plugin_settings_link($links) {
    $settings_link = '<a href="options-general.php?page=lisence_key_setting">Settings</a>';
    array_push($links, $settings_link);
    return $links;
}

// Hook to add an admin menu for the plugin settings
add_action('admin_menu', 'my_custom_plugin_create_settings_page');

function my_custom_plugin_create_settings_page() {
    add_options_page(
        'Lisence Settings',
        'Lisence Settings',
        'manage_options',
        'lisence_key_setting',
        'my_custom_plugin_settings_page'
    );

    // Register the settings
    add_action('admin_init', 'my_custom_plugin_register_settings');
}

function my_custom_plugin_register_settings() {
    register_setting('lisence_key_setting_group', 'lisence_key');
}

function my_custom_plugin_settings_page() {
	include 'admin/partials/whatsapp-api-admin-display.php';
}

function check_lisence_key($key){

$curl = curl_init();
curl_setopt_array($curl, array(
	CURLOPT_URL => 'https://cynorwebsolutions.com/license-key/wp-json/custom/v1/check-lisence?lisence_key='.$key,
	CURLOPT_RETURNTRANSFER => true,
	CURLOPT_ENCODING => '',
	CURLOPT_MAXREDIRS => 10,
	CURLOPT_TIMEOUT => 0,
	CURLOPT_FOLLOWLOCATION => true,
	CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
	CURLOPT_CUSTOMREQUEST => 'GET',
));

$response = curl_exec($curl);

curl_close($curl);
return $response;

}

function register_whatsapp_elementor_form_widget( $widgets_manager ) {
    // require_once( __DIR__ . '/public/partials/elementor-form-widget.php' );
   // $widgets_manager->register( new \Whatsapp_Elementor_Form_Widget() );
   
   require_once( __DIR__ . '/public/partials/custom-cws-widget.php' );
   $widgets_manager->register( new \Custom_Cws_Form_Widget() );
   
}
add_action( 'elementor/widgets/register', 'register_whatsapp_elementor_form_widget' );

function send_whatsapp_on_woocommerce_order($order_id){
	$order = wc_get_order($order_id);
    $phone_number = $order->get_billing_phone();
	$first_name = $order->get_billing_first_name();
	$last_name = $order->get_billing_last_name();
	$comp_name = $order->get_billing_company();
	$cont_name = $order->get_billing_country();
	$stat_name = $order->get_billing_state();
	$country_name = WC()->countries->countries[ $cont_name ];
    $state_name = WC()->countries->states[ $cont_name ][ $stat_name ];
	$city_name = $order->get_billing_city();
	$add1_name = $order->get_billing_address_1();
	$add2_name = $order->get_billing_address_2();
	$emal_name = $order->get_billing_email();
	$order_date = $order->get_date_created()->date_i18n( 'j F Y' );
	$order_time = $order->get_date_created()->date_i18n( 'g:i a' );
	$website = site_url();
	$total = $order->get_total();
	$payment_method = $order->get_payment_method_title();
	$product_name = [];
	foreach ( $order->get_items() as $item_id => $item ) {
		$product_name[] = $item->get_name();
	}
	$product_name = implode(", ",$product_name);
	
	$lisence_key = get_option('lisence_key');
	$whatsapp_number = get_option('whatsapp_no');
	
	$admins = get_users( array( 'role' => 'administrator', 'number' => 1 ) );
	if ( !empty($admins) ) {
		$adminnam = $admins[0]->display_name;
	}else{
		$adminnam = '';
	}
	
	$query_params = array(
		'adminnam' => $adminnam,
		'phone_number' => $phone_number,
		'first_name' => $first_name,
		'last_name' => $last_name,
		'comp_name' => $comp_name,
		'country_name' => $country_name,
		'state_name' => $state_name,
		'city_name' => $city_name,
		'add1_name' => $add1_name,
		'add2_name' => $add2_name,
		'emal_name' => $emal_name,
		'order_date' => $order_date,
		'order_time' => $order_time,
		'website' => $website,
		'total' => $total,
		'product_name' => $product_name,
		'payment_method' => $payment_method,
		'whatsapp' => $whatsapp_number,
		'lisence_key' => $lisence_key,
	);

	$url = 'https://cynorwebsolutions.com/license-key/wp-json/whatsapp/v1/send-whatsapp?' . http_build_query($query_params);
	
	$curl = curl_init();
	curl_setopt_array($curl, array(
		CURLOPT_URL => $url,
		CURLOPT_RETURNTRANSFER => true,
		CURLOPT_ENCODING => '',
		CURLOPT_MAXREDIRS => 10,
		CURLOPT_TIMEOUT => 300,
		CURLOPT_FOLLOWLOCATION => true,
		CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
		CURLOPT_CUSTOMREQUEST => 'GET',
	));

	$response = curl_exec($curl);

	if ($response === false) {
		$errorNo = curl_errno($curl); // Get error number
		$errorMsg = curl_error($curl); // Get error message
		//echo "cURL error ({$errorNo}): {$errorMsg}";
	} else {
		//echo "Response: " . $response;
	}

	curl_close($curl);
}

add_action('woocommerce_thankyou', 'send_whatsapp_on_woocommerce_order', 10, 1);

add_action('init', 'process_whatsmarketing_elementor_submit_form',10);

function process_whatsmarketing_elementor_submit_form(){
	if(isset($_POST['whatsmarketing_elementor_submit'])) {
		
		$recaptcha_secret_key = get_option('whatsapp_recap_secret_key');
		
		if ( isset( $_POST['g-recaptcha-response'] ) && ! empty( $_POST['g-recaptcha-response'] ) ) {
			$recaptcha_response = sanitize_text_field( $_POST['g-recaptcha-response'] );

			$response = wp_remote_get( "https://www.google.com/recaptcha/api/siteverify?secret={$recaptcha_secret_key}&response={$recaptcha_response}" );
			$response_body = wp_remote_retrieve_body( $response );
			$result = json_decode( $response_body );
			
			if ( ! $result->success || $result->score < 0.5 ) {
				wp_die( 'reCAPTCHA verification failed. Please try again.' );
			}
		}

		$phone_number = $_POST['form_fields']['wa'];
		$first_name = $_POST['form_fields']['name'];
		$sendmessage = $_POST['form_fields']['message'];
		$whatsappnumber = $_POST['form_fields']['whatsapp'];
		$email = $_POST['form_fields']['email'];
		$website = site_url();
		$lisence_key = get_option('lisence_key');

		// Build the query parameters
		$query_params = array(
			'wa' => $phone_number,
			'name' => $first_name,
			'message' => $sendmessage,
			'website' => $website,
			'whatsapp' => $whatsappnumber,
			'email' => $email,
			'lisence_key' => $lisence_key
		);

		// Properly encode the parameters and append to the base URL
		$url = 'https://cynorwebsolutions.com/license-key/wp-json/elementor/v1/send-elementor?' . http_build_query($query_params);

		$curl = curl_init();
		curl_setopt_array($curl, array(
			CURLOPT_URL => $url,
			CURLOPT_RETURNTRANSFER => true,
			CURLOPT_ENCODING => '',
			CURLOPT_MAXREDIRS => 10,
			CURLOPT_TIMEOUT => 300,
			CURLOPT_FOLLOWLOCATION => true,
			CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
			CURLOPT_CUSTOMREQUEST => 'GET',
		));

		$response = curl_exec($curl);

		if ($response === false) {
			$errorNo = curl_errno($curl); // Get error number
			$errorMsg = curl_error($curl); // Get error message
			//echo "cURL error ({$errorNo}): {$errorMsg}";
		} else {
			//echo "Response: " . $response;
		}

		curl_close($curl);
	}
}

/////// Add country code in Elementor Form ///////

function add_tel_footer_script(){
?>
<link
    rel="stylesheet"
    href="https://cdnjs.cloudflare.com/ajax/libs/intl-tel-input/17.0.8/css/intlTelInput.css"
/>
<script src="https://cdnjs.cloudflare.com/ajax/libs/intl-tel-input/17.0.8/js/intlTelInput.min.js"></script>
<script>
 document.addEventListener('DOMContentLoaded', function() {
    const phoneInputField = document.querySelector("#form-field-wa");
    const iti1 = window.intlTelInput(phoneInputField, {
        initialCountry: "PE",
        geoIpLookup: function(callback) {
            fetch('https://ipinfo.io/json')
                .then(response => response.json())
                .then(ipdata => callback(ipdata.country))
                .catch(() => callback('PE'));
        },
        utilsScript: "https://cdnjs.cloudflare.com/ajax/libs/intl-tel-input/17.0.8/js/utils.js"
    });

    function updateCountryCode() {
        const countryData = iti1.getSelectedCountryData();
        if (countryData && countryData.dialCode) {
            const countryCode = "+" + countryData.dialCode;
            if (!phoneInputField.value.startsWith(countryCode)) {
                phoneInputField.value = countryCode;
            }
        }
    }

    function validatePhoneNumber(){
        const phoneNumber = phoneInputField.value;
        if (iti1.isValidNumber()){
            
            phoneInputField.style.borderColor = "green";
           
        } else {
            
            phoneInputField.style.borderColor = "red";
           
        }
    }

    updateCountryCode();

    phoneInputField.addEventListener('countrychange', updateCountryCode);
    phoneInputField.addEventListener('input', validatePhoneNumber);
});

</script>
<?php
}

add_action('wp_footer', 'add_tel_footer_script',100);
