<?php
if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly.
}

class Custom_Cws_Form_Widget extends \Elementor\Widget_Base {

    public function get_name() {
        return 'custom_elementor_form';
    }

    public function get_title() {
        return __( 'Custom Form', 'custom-elementor-form' );
    }

    public function get_icon() {
        return 'fa fa-envelope';
    }

    public function get_categories() {
        return [ 'general' ];
    }

    protected function _register_controls() {
        // Section for form title
        $this->start_controls_section(
            'section_content',
            [
                'label' => __( 'Form Settings', 'custom-elementor-form' ),
            ]
        );

        $this->add_control(
            'form_title',
            [
                'label' => __( 'Form Title', 'custom-elementor-form' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( 'Custom Form', 'custom-elementor-form' ),
            ]
        );

        // Add a repeater control to let admin add multiple fields
        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'field_label',
            [
                'label' => __( 'Field Label', 'custom-elementor-form' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( 'Field Label', 'custom-elementor-form' ),
                'label_block' => true,
            ]
        );

        $repeater->add_control(
            'field_type',
            [
                'label' => __( 'Field Type', 'custom-elementor-form' ),
                'type' => \Elementor\Controls_Manager::SELECT,
                'options' => [
                    'text' => __( 'Text', 'custom-elementor-form' ),
                    'email' => __( 'Email', 'custom-elementor-form' ),
                    'textarea' => __( 'Textarea', 'custom-elementor-form' ),
                ],
                'default' => 'text',
            ]
        );

        $this->add_control(
            'form_fields',
            [
                'label' => __( 'Form Fields', 'custom-elementor-form' ),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'field_label' => __( 'Name', 'custom-elementor-form' ),
                        'field_type' => 'text',
                    ],
                    [
                        'field_label' => __( 'Email', 'custom-elementor-form' ),
                        'field_type' => 'email',
                    ],
                ],
                'title_field' => '{{{ field_label }}}',
            ]
        );

        $this->end_controls_section();
    }

    protected function render() {
        $settings = $this->get_settings_for_display();
        ?>

        <div class="custom-elementor-form">
            <h2><?php echo $settings['form_title']; ?></h2>
            <form action="" method="post">
                <?php
                if ( ! empty( $settings['form_fields'] ) ) {
                    foreach ( $settings['form_fields'] as $field ) {
                        echo '<p>';
                        echo '<label for="' . esc_attr( strtolower( $field['field_label'] ) ) . '">' . esc_html( $field['field_label'] ) . '</label>';

                        if ( $field['field_type'] === 'textarea' ) {
                            echo '<textarea name="' . esc_attr( strtolower( $field['field_label'] ) ) . '" id="' . esc_attr( strtolower( $field['field_label'] ) ) . '" required></textarea>';
                        } else {
                            echo '<input type="' . esc_attr( $field['field_type'] ) . '" name="' . esc_attr( strtolower( $field['field_label'] ) ) . '" id="' . esc_attr( strtolower( $field['field_label'] ) ) . '" required>';
                        }

                        echo '</p>';
                    }
                }
                ?>
                <p>
                    <input type="submit" value="<?php _e( 'Submit', 'custom-elementor-form' ); ?>">
                </p>
            </form>
        </div>

        <?php
    }

    protected function _content_template() {
        ?>
        <div class="custom-elementor-form">
            <h2>{{{ settings.form_title }}}</h2>
            <form action="" method="post">
                <# if ( settings.form_fields.length ) { #>
                    <# _.each( settings.form_fields, function( field ) { #>
                        <p>
                            <label for="{{ field.field_label }}">{{ field.field_label }}</label>
                            <# if ( field.field_type === 'textarea' ) { #>
                                <textarea name="{{ field.field_label }}" id="{{ field.field_label }}" required></textarea>
                            <# } else { #>
                                <input type="{{ field.field_type }}" name="{{ field.field_label }}" id="{{ field.field_label }}" required>
                            <# } #>
                        </p>
                    <# }); #>
                <# } #>
                <p>
                    <input type="submit" value="<?php _e( 'Submit', 'custom-elementor-form' ); ?>">
                </p>
            </form>
        </div>
        <?php
    }
}
