<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://cynorwebsolutions.com
 * @since             1.0.0
 * @package           Whatsapp_Api
 *
 * @wordpress-plugin
 * Plugin Name:       whatsapp api
 * Plugin URI:        https://cynorwebsolutions.com
 * Description:       This is a description of the plugin.
 * Version:           1.0.0
 * Author:            cws
 * Author URI:        https://cynorwebsolutions.com/
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       whatsapp-api
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'WHATSAPP_API_VERSION', '1.0.0' );

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-whatsapp-api-activator.php
 */
function activate_whatsapp_api() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-whatsapp-api-activator.php';
	Whatsapp_Api_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-whatsapp-api-deactivator.php
 */
function deactivate_whatsapp_api() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-whatsapp-api-deactivator.php';
	Whatsapp_Api_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_whatsapp_api' );
register_deactivation_hook( __FILE__, 'deactivate_whatsapp_api' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-whatsapp-api.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_whatsapp_api() {

	$plugin = new Whatsapp_Api();
	$plugin->run();

}
run_whatsapp_api();

// Hook to add settings link on the plugins page
add_filter('plugin_action_links_' . plugin_basename(__FILE__), 'my_custom_plugin_settings_link');

function my_custom_plugin_settings_link($links) {
    $settings_link = '<a href="options-general.php?page=lisence_key_setting">Settings</a>';
    array_push($links, $settings_link);
    return $links;
}

// Hook to add an admin menu for the plugin settings
add_action('admin_menu', 'my_custom_plugin_create_settings_page');

function my_custom_plugin_create_settings_page() {
    add_options_page(
        'Lisence Settings',
        'Lisence Settings',
        'manage_options',
        'lisence_key_setting',
        'my_custom_plugin_settings_page'
    );

    // Register the settings
    add_action('admin_init', 'my_custom_plugin_register_settings');
}

function my_custom_plugin_register_settings() {
    register_setting('lisence_key_setting_group', 'lisence_key');
}

function my_custom_plugin_settings_page() {
?>
<div class="wrap">
    <h1>Lisence Settings</h1>
    <form method="post" action="options.php">
        <?php
        settings_fields('lisence_key_setting_group');
        do_settings_sections('lisence-key-setting');
        ?>
        <table class="form-table">
            <tr valign="top">
            <th scope="row">Lisence Key</th>
            <td><input type="text" name="lisence_key" value="<?php echo esc_attr(get_option('lisence_key')); ?>" /></td>
            </tr>
        </table>
        <?php submit_button(); ?>
    </form>
</div>
<?php
}

function register_whatsapp_elementor_form_widget( $widgets_manager ) {
    require_once( __DIR__ . '/public/partials/elementor-form-widget.php' );
    $widgets_manager->register( new \Whatsapp_Elementor_Form_Widget() );
}
add_action( 'elementor/widgets/register', 'register_whatsapp_elementor_form_widget' );