<style>
.custom-elementor-form {
    background-color: #f9f9f9;
    padding: 30px;
    border-radius: 10px;
    max-width: 600px;
    margin: 20px auto;
    box-shadow: 0 4px 8px rgba(0, 0, 0, 0.1);
}

.custom-elementor-form h2 {
     font-weight:600;
    font-size: 30px;
    margin-bottom: 20px;
    color: #000;
    text-align: center;
}

.custom-elementor-form form {
    display: flex;
    flex-direction: column;
}

.custom-elementor-form p {
    margin-bottom: 12px;
}

.custom-elementor-form label {
    font-weight:600;
    margin-bottom: 5px;
    display: block;
    color: #000;
}

.custom-elementor-form input[type="text"],
.custom-elementor-form input[type="tel"],
.custom-elementor-form input[type="email"],
.custom-elementor-form textarea {
    width: 100%;
    padding: 10px;
    border: 1px solid #ccc;
    border-radius: 5px;
    font-size: 16px;
    background-color: #fff;
    box-sizing: border-box;
}

.custom-elementor-form textarea {
    height: 100px;
    resize: none;
}

.custom-elementor-form input[type="submit"] {
    background-color: #28a745;
    color: #fff;
    border: none;
    padding: 10px 15px;
    font-size: 16px;
    cursor: pointer;
    border-radius: 5px;
    transition: background-color 0.3s ease;
}

.custom-elementor-form input[type="submit"]:hover {
    background-color: #008000;
}
.iti.iti--allow-dropdown {
    width: 100%;
}

@media(max-width:767px){
    .custom-elementor-form {
    padding: 20px;
}
}

</style>

<?php
if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly.
}

class Custom_Cws_Form_Widget extends \Elementor\Widget_Base {

    public function get_name() {
        return 'whatsapp_elementor_form';
    }

    public function get_title() {
        return __( 'Whatsapp Form', 'custom-elementor-form' );
    }

    public function get_icon() {
        return 'fa fa-envelope';
    }

    public function get_categories() {
        return [ 'general' ];
    }

    protected function _register_controls() {
        $this->start_controls_section(
            'section_content',
            [
                'label' => __( 'Form Settings', 'custom-elementor-form' ),
            ]
        );

        $this->add_control(
            'form_title',
            [
                'label' => __( 'Form Title', 'custom-elementor-form' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( 'Demo Elementor Form to WhatsApp', 'custom-elementor-form' ),
            ]
        );

        // Name Field Label
        $this->add_control(
            'name_label',
            [
                'label' => __( 'Name Field Label', 'custom-elementor-form' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( 'Nama', 'custom-elementor-form' ),
            ]
        );

        // WhatsApp Number Field Label
        $this->add_control(
            'whatsapp_label',
            [
                'label' => __( 'WhatsApp Number Field Label', 'custom-elementor-form' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( 'Nomor WA', 'custom-elementor-form' ),
            ]
        );

        // Email Field Label
        $this->add_control(
            'email_label',
            [
                'label' => __( 'Email Field Label', 'custom-elementor-form' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( 'Email', 'custom-elementor-form' ),
            ]
        );

        // Message Field Label
        $this->add_control(
            'message_label',
            [
                'label' => __( 'Message Field Label', 'custom-elementor-form' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( 'Pesan', 'custom-elementor-form' ),
            ]
        );

        // Submit Button Label
        $this->add_control(
            'submit_label',
            [
                'label' => __( 'Submit Button Label', 'custom-elementor-form' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( 'SEND', 'custom-elementor-form' ),
            ]
        );

        $this->end_controls_section();
		
		$this->start_controls_section(
			'recaptcha_section',
			[
				'label' => __( 'reCAPTCHA Settings', 'custom-elementor-form' ),
			]
		);

		// Enable reCAPTCHA toggle
		$this->add_control(
			'enable_recaptcha',
			[
				'label' => __( 'Enable reCAPTCHA v3', 'custom-elementor-form' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'Yes', 'custom-elementor-form' ),
				'label_off' => __( 'No', 'custom-elementor-form' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);

		// reCAPTCHA Site Key field
		$this->add_control(
			'recaptcha_site_key',
			[
				'label' => __( 'reCAPTCHA Site Key', 'custom-elementor-form' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'condition' => [
					'enable_recaptcha' => 'yes',
				],
			]
		);

		// reCAPTCHA Secret Key field
		$this->add_control(
			'recaptcha_secret_key',
			[
				'label' => __( 'reCAPTCHA Secret Key', 'custom-elementor-form' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'condition' => [
					'enable_recaptcha' => 'yes',
				],
			]
		);

		$this->end_controls_section();
		
    }

    protected function render() {
        $settings = $this->get_settings_for_display();
		$enable_recaptcha = $settings['enable_recaptcha'];
		$recaptcha_site_key = $settings['recaptcha_site_key'];
		$recaptcha_secret_key = $settings['recaptcha_secret_key'];
		
		update_option('whatsapp_recap_site_key',$recaptcha_site_key);
		update_option('whatsapp_recap_secret_key',$recaptcha_secret_key);
		
        ?>

        <div class="custom-elementor-form">
            <h2><?php echo $settings['form_title']; ?></h2>
            <form action="" method="post" class="WhatsApp_form" id="elm_to_wts">
                <p>
                    <label for="name"><?php echo $settings['name_label']; ?></label>
                    <input type="text" name="form_fields[name]" id="name" required>
                </p>
                <p>
                    <label for="whatsapp"><?php echo $settings['whatsapp_label']; ?></label>
                    <input type="tel" name="form_fields[wa]" id="form-field-wa" placeholder="+51" required>
                </p>
				<?php
				$whatsapp_number = get_option('whatsapp_no');
				?>
				<input type="hidden" name="form_fields[whatsapp]" value='<?=$whatsapp_number?>'>
                <p>
                    <label for="email"><?php echo $settings['email_label']; ?></label>
                    <input type="email" name="form_fields[email]" id="email" required>
                </p>
                <p>
                    <label for="message"><?php echo $settings['message_label']; ?></label>
                    <textarea name="form_fields[message]" id="message" placeholder="Asal aja hanya untuk demo" required></textarea>
                </p>
				<?php if ( 'yes' === $enable_recaptcha && ! empty( $recaptcha_site_key ) ) : ?>
					<input type="hidden" name="g-recaptcha-response" id="g-recaptcha-response">
					<script src="https://www.google.com/recaptcha/api.js?render=<?php echo esc_attr( $recaptcha_site_key ); ?>"></script>
					<script>
						grecaptcha.ready(function() {
							grecaptcha.execute('<?php echo esc_attr( $recaptcha_site_key ); ?>', {action: 'submit'}).then(function(token) {
								document.getElementById('g-recaptcha-response').value = token;
							});
						});
					</script>
				<?php endif; ?>
                <p>
                    <input type="submit" name="whatsmarketing_elementor_submit" id="whatsmarketing_elementor_submit" value="<?php echo $settings['submit_label']; ?>">
                </p>
            </form>
        </div>
        <?php
    }

    protected function _content_template() {
        ?>
        <div class="custom-elementor-form">
            <h2>{{{ settings.form_title }}}</h2>
            <form action="" method="post">
                <p>
                    <label for="name">{{{ settings.name_label }}}</label>
                    <input type="text" name="name" id="name" required>
                </p>
                <p>
                    <label for="whatsapp">{{{ settings.whatsapp_label }}}</label>
                    <input type="tel" name="whatsapp" id="whatsapp" placeholder="+51" required>
                </p>
                <p>
                    <label for="email">{{{ settings.email_label }}}</label>
                    <input type="email" name="email" id="email" required>
                </p>
                <p>
                    <label for="message">{{{ settings.message_label }}}</label>
                    <textarea name="message" id="message" placeholder="Asal aja hanya untuk demo" required></textarea>
                </p>
                <p>
                    <input type="submit" value="{{{ settings.submit_label }}}">
                </p>
            </form>
        </div>
        <?php
    }
}

